@@ -1,5 +1,10 @@
 package MooseX::MethodAttributes::Inheritable;
-our $VERSION = '0.19';
+{
+  $MooseX::MethodAttributes::Inheritable::VERSION = '0.29';
+}
+BEGIN {
+  $MooseX::MethodAttributes::Inheritable::AUTHORITY = 'cpan:FLORA';
+}
 # ABSTRACT: inheritable code attribute introspection
 
 
@@ -8,24 +13,28 @@ use MooseX::MethodAttributes::Role::Meta::Role ();
 
 use Moose;
 
-use namespace::clean -except => 'meta';
+use namespace::autoclean;
 
 with 'MooseX::MethodAttributes::Role::AttrContainer::Inheritable';
 
 __PACKAGE__->meta->make_immutable;
-
+1;
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
+=for :stopwords Florian Ragwitz Tomas Doran
+
 =head1 NAME
 
 MooseX::MethodAttributes::Inheritable - inheritable code attribute introspection
 
 =head1 VERSION
 
-version 0.19
+version 0.29
 
 =head1 SYNOPSIS
 
@@ -45,20 +54,28 @@ This module does the same as C<MooseX::MethodAttributes>, except that classes
 inheriting from other classes using it don't need to do anything special to get
 their code attributes captured.
 
-
+Note that instead of inheriting from this module, you can instead simply
+compose (C<with>) the L<MooseX::MethodAttributes::Role::AttrContainer::Inheritable> role.
 
 =head1 AUTHORS
 
-  Florian Ragwitz <rafl@debian.org>
-  Tomas Doran <bobtfish@bobtfish.net>
+=over 4
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Tomas Doran <bobtfish@bobtfish.net>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Florian Ragwitz.
+This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
-
+=cut
