@@ -1,17 +1,17 @@
 package MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped;
+{
+  $MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped::VERSION = '0.29';
+}
 BEGIN {
   $MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped::AUTHORITY = 'cpan:FLORA';
 }
-{
-  $MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped::VERSION = '0.26';
-}
 # ABSTRACT: proxy attributes of wrapped methods if their metaclass supports it
 
 use Moose::Role;
 use Moose::Util qw/does_role/;
 use MooseX::MethodAttributes::Role::Meta::Method::Wrapped;
 
-use namespace::clean -except => 'meta';
+use namespace::autoclean;
 
 override wrap => sub {
     my $self = super;
@@ -28,14 +28,22 @@ override wrap => sub {
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
+
+=for :stopwords Florian Ragwitz Tomas Doran Dave Karman (t0m) Rolsky David Steinbrunner
+Karen Etheridge Marcus Ramberg Peter E
 
 =head1 NAME
 
 MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped - proxy attributes of wrapped methods if their metaclass supports it
 
+=head1 VERSION
+
+version 0.29
+
 =head1 AUTHORS
 
 =over 4
@@ -52,10 +60,9 @@ Tomas Doran <bobtfish@bobtfish.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Florian Ragwitz.
+This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
