@@ -1,11 +1,15 @@
 package MooseX::MethodAttributes::Role::Meta::Method::Wrapped;
-our $VERSION = '0.14';
-
+{
+  $MooseX::MethodAttributes::Role::Meta::Method::Wrapped::VERSION = '0.29';
+}
+BEGIN {
+  $MooseX::MethodAttributes::Role::Meta::Method::Wrapped::AUTHORITY = 'cpan:FLORA';
+}
 # ABSTRACT: wrapped metamethod role allowing code attribute introspection
 
 use Moose::Role;
 
-use namespace::clean -except => 'meta';
+use namespace::autoclean;
 
 
 sub attributes {
@@ -21,13 +25,20 @@ sub _get_attributed_coderef {
 1;
 
 __END__
+
+=pod
+
+=encoding UTF-8
+
+=for :stopwords Florian Ragwitz Tomas Doran metamethod
+
 =head1 NAME
 
 MooseX::MethodAttributes::Role::Meta::Method::Wrapped - wrapped metamethod role allowing code attribute introspection
 
 =head1 VERSION
 
-version 0.14
+version 0.29
 
 =head1 METHODS
 
@@ -37,13 +48,23 @@ Gets the list of code attributes of the original method this meta method wraps.
 
 =head1 AUTHORS
 
-  Florian Ragwitz <rafl@debian.org>
-  Tomas Doran <bobtfish@bobtfish.net>
+=over 4
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Tomas Doran <bobtfish@bobtfish.net>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
+the same terms as the Perl 5 programming language system itself.
 
+=cut
