@@ -1,17 +1,18 @@
 package MooseX::MethodAttributes::Role::Meta::Role::Application;
+{
+  $MooseX::MethodAttributes::Role::Meta::Role::Application::VERSION = '0.29';
+}
 BEGIN {
   $MooseX::MethodAttributes::Role::Meta::Role::Application::AUTHORITY = 'cpan:FLORA';
 }
-{
-  $MooseX::MethodAttributes::Role::Meta::Role::Application::VERSION = '0.26';
-}
 # ABSTRACT: generic role for applying a role with method attributes to something
 
 use Moose::Role;
 use Moose::Util qw/find_meta/;
 use MooseX::MethodAttributes ();
 use MooseX::MethodAttributes::Role ();
-use namespace::clean -except => 'meta';
+use Carp qw/croak/;
+use namespace::autoclean;
 
 requires qw/
     _copy_attributes
@@ -52,14 +53,21 @@ sub _apply_metaclasses {
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
+
+=for :stopwords Florian Ragwitz Tomas Doran
 
 =head1 NAME
 
 MooseX::MethodAttributes::Role::Meta::Role::Application - generic role for applying a role with method attributes to something
 
+=head1 VERSION
+
+version 0.29
+
 =head1 METHODS
 
 =head2 apply
@@ -85,10 +93,9 @@ Tomas Doran <bobtfish@bobtfish.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Florian Ragwitz.
+This software is copyright (c) 2009 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
